# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/account_budget_proposal_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/account_budget_proposal_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\037AccountBudgetProposalErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\nHgoogle/ads/googleads_v1/proto/errors/account_budget_proposal_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xd4\x06\n\x1e\x41\x63\x63ountBudgetProposalErrorEnum\"\xb1\x06\n\x1a\x41\x63\x63ountBudgetProposalError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1a\n\x16\x46IELD_MASK_NOT_ALLOWED\x10\x02\x12\x13\n\x0fIMMUTABLE_FIELD\x10\x03\x12\x1a\n\x16REQUIRED_FIELD_MISSING\x10\x04\x12#\n\x1f\x43\x41NNOT_CANCEL_APPROVED_PROPOSAL\x10\x05\x12#\n\x1f\x43\x41NNOT_REMOVE_UNAPPROVED_BUDGET\x10\x06\x12 \n\x1c\x43\x41NNOT_REMOVE_RUNNING_BUDGET\x10\x07\x12 \n\x1c\x43\x41NNOT_END_UNAPPROVED_BUDGET\x10\x08\x12\x1e\n\x1a\x43\x41NNOT_END_INACTIVE_BUDGET\x10\t\x12\x18\n\x14\x42UDGET_NAME_REQUIRED\x10\n\x12\x1c\n\x18\x43\x41NNOT_UPDATE_OLD_BUDGET\x10\x0b\x12\x16\n\x12\x43\x41NNOT_END_IN_PAST\x10\x0c\x12\x1a\n\x16\x43\x41NNOT_EXTEND_END_TIME\x10\r\x12\"\n\x1ePURCHASE_ORDER_NUMBER_REQUIRED\x10\x0e\x12\"\n\x1ePENDING_UPDATE_PROPOSAL_EXISTS\x10\x0f\x12=\n9MULTIPLE_BUDGETS_NOT_ALLOWED_FOR_UNAPPROVED_BILLING_SETUP\x10\x10\x12/\n+CANNOT_UPDATE_START_TIME_FOR_STARTED_BUDGET\x10\x11\x12\x36\n2SPENDING_LIMIT_LOWER_THAN_ACCRUED_COST_NOT_ALLOWED\x10\x12\x12\x13\n\x0fUPDATE_IS_NO_OP\x10\x13\x12#\n\x1f\x45ND_TIME_MUST_FOLLOW_START_TIME\x10\x14\x12\x35\n1BUDGET_DATE_RANGE_INCOMPATIBLE_WITH_BILLING_SETUP\x10\x15\x12\x12\n\x0eNOT_AUTHORIZED\x10\x16\x12\x19\n\x15INVALID_BILLING_SETUP\x10\x17\x42\xfa\x01\n\"com.google.ads.googleads.v1.errorsB\x1f\x41\x63\x63ountBudgetProposalErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_ACCOUNTBUDGETPROPOSALERRORENUM_ACCOUNTBUDGETPROPOSALERROR = _descriptor.EnumDescriptor(
  name='AccountBudgetProposalError',
  full_name='google.ads.googleads.v1.errors.AccountBudgetProposalErrorEnum.AccountBudgetProposalError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIELD_MASK_NOT_ALLOWED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMMUTABLE_FIELD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUIRED_FIELD_MISSING', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CANCEL_APPROVED_PROPOSAL', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_REMOVE_UNAPPROVED_BUDGET', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_REMOVE_RUNNING_BUDGET', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_END_UNAPPROVED_BUDGET', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_END_INACTIVE_BUDGET', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUDGET_NAME_REQUIRED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_UPDATE_OLD_BUDGET', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_END_IN_PAST', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_EXTEND_END_TIME', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PURCHASE_ORDER_NUMBER_REQUIRED', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PENDING_UPDATE_PROPOSAL_EXISTS', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLE_BUDGETS_NOT_ALLOWED_FOR_UNAPPROVED_BILLING_SETUP', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_UPDATE_START_TIME_FOR_STARTED_BUDGET', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPENDING_LIMIT_LOWER_THAN_ACCRUED_COST_NOT_ALLOWED', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE_IS_NO_OP', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END_TIME_MUST_FOLLOW_START_TIME', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUDGET_DATE_RANGE_INCOMPATIBLE_WITH_BILLING_SETUP', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_AUTHORIZED', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_BILLING_SETUP', index=23, number=23,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=174,
  serialized_end=991,
)
_sym_db.RegisterEnumDescriptor(_ACCOUNTBUDGETPROPOSALERRORENUM_ACCOUNTBUDGETPROPOSALERROR)


_ACCOUNTBUDGETPROPOSALERRORENUM = _descriptor.Descriptor(
  name='AccountBudgetProposalErrorEnum',
  full_name='google.ads.googleads.v1.errors.AccountBudgetProposalErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACCOUNTBUDGETPROPOSALERRORENUM_ACCOUNTBUDGETPROPOSALERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=991,
)

_ACCOUNTBUDGETPROPOSALERRORENUM_ACCOUNTBUDGETPROPOSALERROR.containing_type = _ACCOUNTBUDGETPROPOSALERRORENUM
DESCRIPTOR.message_types_by_name['AccountBudgetProposalErrorEnum'] = _ACCOUNTBUDGETPROPOSALERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccountBudgetProposalErrorEnum = _reflection.GeneratedProtocolMessageType('AccountBudgetProposalErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTBUDGETPROPOSALERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.account_budget_proposal_error_pb2'
  ,
  __doc__ = """Container for enum describing possible account budget proposal errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.AccountBudgetProposalErrorEnum)
  ))
_sym_db.RegisterMessage(AccountBudgetProposalErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/user_list_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/user_list_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\022UserListErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n:google/ads/googleads_v2/proto/errors/user_list_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xec\x07\n\x11UserListErrorEnum\"\xd6\x07\n\rUserListError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x37\n3EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED\x10\x02\x12\x1a\n\x16\x43ONCRETE_TYPE_REQUIRED\x10\x03\x12\x1f\n\x1b\x43ONVERSION_TYPE_ID_REQUIRED\x10\x04\x12\x1e\n\x1a\x44UPLICATE_CONVERSION_TYPES\x10\x05\x12\x1b\n\x17INVALID_CONVERSION_TYPE\x10\x06\x12\x17\n\x13INVALID_DESCRIPTION\x10\x07\x12\x10\n\x0cINVALID_NAME\x10\x08\x12\x10\n\x0cINVALID_TYPE\x10\t\x12\x34\n0CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND\x10\n\x12*\n&INVALID_USER_LIST_LOGICAL_RULE_OPERAND\x10\x0b\x12\x15\n\x11NAME_ALREADY_USED\x10\x0c\x12%\n!NEW_CONVERSION_TYPE_NAME_REQUIRED\x10\r\x12%\n!CONVERSION_TYPE_NAME_ALREADY_USED\x10\x0e\x12\x1e\n\x1aOWNERSHIP_REQUIRED_FOR_SET\x10\x0f\x12\"\n\x1eUSER_LIST_MUTATE_NOT_SUPPORTED\x10\x10\x12\x10\n\x0cINVALID_RULE\x10\x11\x12\x16\n\x12INVALID_DATE_RANGE\x10\x1b\x12%\n!CAN_NOT_MUTATE_SENSITIVE_USERLIST\x10\x1c\x12\x1f\n\x1bMAX_NUM_RULEBASED_USERLISTS\x10\x1d\x12\'\n#CANNOT_MODIFY_BILLABLE_RECORD_COUNT\x10\x1e\x12\x12\n\x0e\x41PP_ID_NOT_SET\x10\x1f\x12-\n)USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST\x10 \x12\x36\n2ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA\x10!\x12\x1e\n\x1aRULE_TYPE_IS_NOT_SUPPORTED\x10\"\x12:\n6CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND\x10#\x12:\n6CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS\x10$B\xed\x01\n\"com.google.ads.googleads.v2.errorsB\x12UserListErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_USERLISTERRORENUM_USERLISTERROR = _descriptor.EnumDescriptor(
  name='UserListError',
  full_name='google.ads.googleads.v2.errors.UserListErrorEnum.UserListError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONCRETE_TYPE_REQUIRED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TYPE_ID_REQUIRED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_CONVERSION_TYPES', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CONVERSION_TYPE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DESCRIPTION', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NAME', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TYPE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_USER_LIST_LOGICAL_RULE_OPERAND', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_ALREADY_USED', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEW_CONVERSION_TYPE_NAME_REQUIRED', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TYPE_NAME_ALREADY_USED', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OWNERSHIP_REQUIRED_FOR_SET', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_LIST_MUTATE_NOT_SUPPORTED', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_RULE', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DATE_RANGE', index=18, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAN_NOT_MUTATE_SENSITIVE_USERLIST', index=19, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAX_NUM_RULEBASED_USERLISTS', index=20, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_MODIFY_BILLABLE_RECORD_COUNT', index=21, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_ID_NOT_SET', index=22, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST', index=23, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA', index=24, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RULE_TYPE_IS_NOT_SUPPORTED', index=25, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND', index=26, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS', index=27, number=36,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=147,
  serialized_end=1129,
)
_sym_db.RegisterEnumDescriptor(_USERLISTERRORENUM_USERLISTERROR)


_USERLISTERRORENUM = _descriptor.Descriptor(
  name='UserListErrorEnum',
  full_name='google.ads.googleads.v2.errors.UserListErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERLISTERRORENUM_USERLISTERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=1129,
)

_USERLISTERRORENUM_USERLISTERROR.containing_type = _USERLISTERRORENUM
DESCRIPTOR.message_types_by_name['UserListErrorEnum'] = _USERLISTERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserListErrorEnum = _reflection.GeneratedProtocolMessageType('UserListErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.user_list_error_pb2'
  ,
  __doc__ = """Container for enum describing possible user list errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.UserListErrorEnum)
  ))
_sym_db.RegisterMessage(UserListErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/custom_interest_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import custom_interest_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_custom__interest__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/custom_interest_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\032CustomInterestServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nDgoogle/ads/googleads_v1/proto/services/custom_interest_service.proto\x12 google.ads.googleads.v1.services\x1a=google/ads/googleads_v1/proto/resources/custom_interest.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\"1\n\x18GetCustomInterestRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x99\x01\n\x1cMutateCustomInterestsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12M\n\noperations\x18\x02 \x03(\x0b\x32\x39.google.ads.googleads.v1.services.CustomInterestOperation\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\xe1\x01\n\x17\x43ustomInterestOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x43\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x31.google.ads.googleads.v1.resources.CustomInterestH\x00\x12\x43\n\x06update\x18\x02 \x01(\x0b\x32\x31.google.ads.googleads.v1.resources.CustomInterestH\x00\x42\x0b\n\toperation\"n\n\x1dMutateCustomInterestsResponse\x12M\n\x07results\x18\x02 \x03(\x0b\x32<.google.ads.googleads.v1.services.MutateCustomInterestResult\"3\n\x1aMutateCustomInterestResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xb3\x03\n\x15\x43ustomInterestService\x12\xbd\x01\n\x11GetCustomInterest\x12:.google.ads.googleads.v1.services.GetCustomInterestRequest\x1a\x31.google.ads.googleads.v1.resources.CustomInterest\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/{resource_name=customers/*/customInterests/*}\x12\xd9\x01\n\x15MutateCustomInterests\x12>.google.ads.googleads.v1.services.MutateCustomInterestsRequest\x1a?.google.ads.googleads.v1.services.MutateCustomInterestsResponse\"?\x82\xd3\xe4\x93\x02\x39\"4/v1/customers/{customer_id=*}/customInterests:mutate:\x01*B\x81\x02\n$com.google.ads.googleads.v1.servicesB\x1a\x43ustomInterestServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_custom__interest__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_GETCUSTOMINTERESTREQUEST = _descriptor.Descriptor(
  name='GetCustomInterestRequest',
  full_name='google.ads.googleads.v1.services.GetCustomInterestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetCustomInterestRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=314,
)


_MUTATECUSTOMINTERESTSREQUEST = _descriptor.Descriptor(
  name='MutateCustomInterestsRequest',
  full_name='google.ads.googleads.v1.services.MutateCustomInterestsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.MutateCustomInterestsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.MutateCustomInterestsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v1.services.MutateCustomInterestsRequest.validate_only', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=470,
)


_CUSTOMINTERESTOPERATION = _descriptor.Descriptor(
  name='CustomInterestOperation',
  full_name='google.ads.googleads.v1.services.CustomInterestOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v1.services.CustomInterestOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v1.services.CustomInterestOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v1.services.CustomInterestOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.CustomInterestOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=473,
  serialized_end=698,
)


_MUTATECUSTOMINTERESTSRESPONSE = _descriptor.Descriptor(
  name='MutateCustomInterestsResponse',
  full_name='google.ads.googleads.v1.services.MutateCustomInterestsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.MutateCustomInterestsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=810,
)


_MUTATECUSTOMINTERESTRESULT = _descriptor.Descriptor(
  name='MutateCustomInterestResult',
  full_name='google.ads.googleads.v1.services.MutateCustomInterestResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.MutateCustomInterestResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=863,
)

_MUTATECUSTOMINTERESTSREQUEST.fields_by_name['operations'].message_type = _CUSTOMINTERESTOPERATION
_CUSTOMINTERESTOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CUSTOMINTERESTOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_custom__interest__pb2._CUSTOMINTEREST
_CUSTOMINTERESTOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_custom__interest__pb2._CUSTOMINTEREST
_CUSTOMINTERESTOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMINTERESTOPERATION.fields_by_name['create'])
_CUSTOMINTERESTOPERATION.fields_by_name['create'].containing_oneof = _CUSTOMINTERESTOPERATION.oneofs_by_name['operation']
_CUSTOMINTERESTOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMINTERESTOPERATION.fields_by_name['update'])
_CUSTOMINTERESTOPERATION.fields_by_name['update'].containing_oneof = _CUSTOMINTERESTOPERATION.oneofs_by_name['operation']
_MUTATECUSTOMINTERESTSRESPONSE.fields_by_name['results'].message_type = _MUTATECUSTOMINTERESTRESULT
DESCRIPTOR.message_types_by_name['GetCustomInterestRequest'] = _GETCUSTOMINTERESTREQUEST
DESCRIPTOR.message_types_by_name['MutateCustomInterestsRequest'] = _MUTATECUSTOMINTERESTSREQUEST
DESCRIPTOR.message_types_by_name['CustomInterestOperation'] = _CUSTOMINTERESTOPERATION
DESCRIPTOR.message_types_by_name['MutateCustomInterestsResponse'] = _MUTATECUSTOMINTERESTSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCustomInterestResult'] = _MUTATECUSTOMINTERESTRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCustomInterestRequest = _reflection.GeneratedProtocolMessageType('GetCustomInterestRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCUSTOMINTERESTREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.custom_interest_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomInterestService.GetCustomInterest][google.ads.googleads.v1.services.CustomInterestService.GetCustomInterest].
  
  
  Attributes:
      resource_name:
          The resource name of the custom interest to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetCustomInterestRequest)
  ))
_sym_db.RegisterMessage(GetCustomInterestRequest)

MutateCustomInterestsRequest = _reflection.GeneratedProtocolMessageType('MutateCustomInterestsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMINTERESTSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.custom_interest_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomInterestService.MutateCustomInterests][google.ads.googleads.v1.services.CustomInterestService.MutateCustomInterests].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose custom interests are being
          modified.
      operations:
          The list of operations to perform on individual custom
          interests.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomInterestsRequest)
  ))
_sym_db.RegisterMessage(MutateCustomInterestsRequest)

CustomInterestOperation = _reflection.GeneratedProtocolMessageType('CustomInterestOperation', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMINTERESTOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.custom_interest_service_pb2'
  ,
  __doc__ = """A single operation (create, update) on a custom interest.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          custom interest.
      update:
          Update operation: The custom interest is expected to have a
          valid resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.CustomInterestOperation)
  ))
_sym_db.RegisterMessage(CustomInterestOperation)

MutateCustomInterestsResponse = _reflection.GeneratedProtocolMessageType('MutateCustomInterestsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMINTERESTSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.custom_interest_service_pb2'
  ,
  __doc__ = """Response message for custom interest mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomInterestsResponse)
  ))
_sym_db.RegisterMessage(MutateCustomInterestsResponse)

MutateCustomInterestResult = _reflection.GeneratedProtocolMessageType('MutateCustomInterestResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMINTERESTRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.custom_interest_service_pb2'
  ,
  __doc__ = """The result for the custom interest mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomInterestResult)
  ))
_sym_db.RegisterMessage(MutateCustomInterestResult)


DESCRIPTOR._options = None

_CUSTOMINTERESTSERVICE = _descriptor.ServiceDescriptor(
  name='CustomInterestService',
  full_name='google.ads.googleads.v1.services.CustomInterestService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=866,
  serialized_end=1301,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCustomInterest',
    full_name='google.ads.googleads.v1.services.CustomInterestService.GetCustomInterest',
    index=0,
    containing_service=None,
    input_type=_GETCUSTOMINTERESTREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_custom__interest__pb2._CUSTOMINTEREST,
    serialized_options=_b('\202\323\344\223\0023\0221/v1/{resource_name=customers/*/customInterests/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCustomInterests',
    full_name='google.ads.googleads.v1.services.CustomInterestService.MutateCustomInterests',
    index=1,
    containing_service=None,
    input_type=_MUTATECUSTOMINTERESTSREQUEST,
    output_type=_MUTATECUSTOMINTERESTSRESPONSE,
    serialized_options=_b('\202\323\344\223\0029\"4/v1/customers/{customer_id=*}/customInterests:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CUSTOMINTERESTSERVICE)

DESCRIPTOR.services_by_name['CustomInterestService'] = _CUSTOMINTERESTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/domain_category.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/domain_category.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\023DomainCategoryProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n=google/ads/googleads_v2/proto/resources/domain_category.proto\x12!google.ads.googleads.v2.resources\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xca\x03\n\x0e\x44omainCategory\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12.\n\x08\x63\x61mpaign\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x63\x61tegory\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rlanguage_code\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x64omain\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x63overage_fraction\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\rcategory_rank\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0chas_children\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x1arecommended_cpc_bid_micros\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x80\x02\n%com.google.ads.googleads.v2.resourcesB\x13\x44omainCategoryProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_DOMAINCATEGORY = _descriptor.Descriptor(
  name='DomainCategory',
  full_name='google.ads.googleads.v2.resources.DomainCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.DomainCategory.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v2.resources.DomainCategory.campaign', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='google.ads.googleads.v2.resources.DomainCategory.category', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='google.ads.googleads.v2.resources.DomainCategory.language_code', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='google.ads.googleads.v2.resources.DomainCategory.domain', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coverage_fraction', full_name='google.ads.googleads.v2.resources.DomainCategory.coverage_fraction', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_rank', full_name='google.ads.googleads.v2.resources.DomainCategory.category_rank', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_children', full_name='google.ads.googleads.v2.resources.DomainCategory.has_children', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_cpc_bid_micros', full_name='google.ads.googleads.v2.resources.DomainCategory.recommended_cpc_bid_micros', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=621,
)

_DOMAINCATEGORY.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DOMAINCATEGORY.fields_by_name['category'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DOMAINCATEGORY.fields_by_name['language_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DOMAINCATEGORY.fields_by_name['domain'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DOMAINCATEGORY.fields_by_name['coverage_fraction'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_DOMAINCATEGORY.fields_by_name['category_rank'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_DOMAINCATEGORY.fields_by_name['has_children'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DOMAINCATEGORY.fields_by_name['recommended_cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['DomainCategory'] = _DOMAINCATEGORY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DomainCategory = _reflection.GeneratedProtocolMessageType('DomainCategory', (_message.Message,), dict(
  DESCRIPTOR = _DOMAINCATEGORY,
  __module__ = 'google.ads.googleads_v2.proto.resources.domain_category_pb2'
  ,
  __doc__ = """A category generated automatically by crawling a domain. If a campaign
  uses the DynamicSearchAdsSetting, then domain categories will be
  generated for the domain. The categories can be targeted using
  WebpageConditionInfo. See:
  https://support.google.com/google-ads/answer/2471185
  
  
  Attributes:
      resource_name:
          The resource name of the domain category. Domain category
          resource names have the form:  ``customers/{customer_id}/domai
          nCategories/{campaign_id}~{category_base64}~{language_code}``
      campaign:
          The campaign this category is recommended for.
      category:
          Recommended category for the website domain. e.g. if you have
          a website about electronics, the categories could be
          "cameras", "televisions", etc.
      language_code:
          The language code specifying the language of the website. e.g.
          "en" for English. The language can be specified in the
          DynamicSearchAdsSetting required for dynamic search ads. This
          is the language of the pages from your website that you want
          Google Ads to find, create ads for, and match searches with.
      domain:
          The domain for the website. The domain can be specified in the
          DynamicSearchAdsSetting required for dynamic search ads.
      coverage_fraction:
          Fraction of pages on your site that this category matches.
      category_rank:
          The position of this category in the set of categories. Lower
          numbers indicate a better match for the domain. null indicates
          not recommended.
      has_children:
          Indicates whether this category has sub-categories.
      recommended_cpc_bid_micros:
          The recommended cost per click for the category.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.DomainCategory)
  ))
_sym_db.RegisterMessage(DomainCategory)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import keyword_plan_keyword_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2
from google.ads.google_ads.v2.proto.services import keyword_plan_keyword_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__keyword__service__pb2


class KeywordPlanKeywordServiceStub(object):
  """Proto file describing the keyword plan keyword service.

  Service to manage Keyword Plan ad group keywords.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetKeywordPlanKeyword = channel.unary_unary(
        '/google.ads.googleads.v2.services.KeywordPlanKeywordService/GetKeywordPlanKeyword',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__keyword__service__pb2.GetKeywordPlanKeywordRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2.KeywordPlanKeyword.FromString,
        )
    self.MutateKeywordPlanKeywords = channel.unary_unary(
        '/google.ads.googleads.v2.services.KeywordPlanKeywordService/MutateKeywordPlanKeywords',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__keyword__service__pb2.MutateKeywordPlanKeywordsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__keyword__service__pb2.MutateKeywordPlanKeywordsResponse.FromString,
        )


class KeywordPlanKeywordServiceServicer(object):
  """Proto file describing the keyword plan keyword service.

  Service to manage Keyword Plan ad group keywords.
  """

  def GetKeywordPlanKeyword(self, request, context):
    """Returns the requested Keyword Plan keyword in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateKeywordPlanKeywords(self, request, context):
    """Creates, updates, or removes Keyword Plan keywords. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_KeywordPlanKeywordServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetKeywordPlanKeyword': grpc.unary_unary_rpc_method_handler(
          servicer.GetKeywordPlanKeyword,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__keyword__service__pb2.GetKeywordPlanKeywordRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2.KeywordPlanKeyword.SerializeToString,
      ),
      'MutateKeywordPlanKeywords': grpc.unary_unary_rpc_method_handler(
          servicer.MutateKeywordPlanKeywords,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__keyword__service__pb2.MutateKeywordPlanKeywordsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__keyword__service__pb2.MutateKeywordPlanKeywordsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.KeywordPlanKeywordService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import customer_client_link_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__client__link__pb2
from google.ads.google_ads.v1.proto.services import customer_client_link_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__client__link__service__pb2


class CustomerClientLinkServiceStub(object):
  """Service to manage customer client links.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCustomerClientLink = channel.unary_unary(
        '/google.ads.googleads.v1.services.CustomerClientLinkService/GetCustomerClientLink',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__client__link__service__pb2.GetCustomerClientLinkRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__client__link__pb2.CustomerClientLink.FromString,
        )
    self.MutateCustomerClientLink = channel.unary_unary(
        '/google.ads.googleads.v1.services.CustomerClientLinkService/MutateCustomerClientLink',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__client__link__service__pb2.MutateCustomerClientLinkRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__client__link__service__pb2.MutateCustomerClientLinkResponse.FromString,
        )


class CustomerClientLinkServiceServicer(object):
  """Service to manage customer client links.
  """

  def GetCustomerClientLink(self, request, context):
    """Returns the requested CustomerClientLink in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCustomerClientLink(self, request, context):
    """Creates or updates a customer client link. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CustomerClientLinkServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCustomerClientLink': grpc.unary_unary_rpc_method_handler(
          servicer.GetCustomerClientLink,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__client__link__service__pb2.GetCustomerClientLinkRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__client__link__pb2.CustomerClientLink.SerializeToString,
      ),
      'MutateCustomerClientLink': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCustomerClientLink,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__client__link__service__pb2.MutateCustomerClientLinkRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__client__link__service__pb2.MutateCustomerClientLinkResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.CustomerClientLinkService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/recommendation_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/recommendation_type.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\027RecommendationTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\n=google/ads/googleads_v2/proto/enums/recommendation_type.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\x92\x03\n\x16RecommendationTypeEnum\"\xf7\x02\n\x12RecommendationType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x13\n\x0f\x43\x41MPAIGN_BUDGET\x10\x02\x12\x0b\n\x07KEYWORD\x10\x03\x12\x0b\n\x07TEXT_AD\x10\x04\x12\x15\n\x11TARGET_CPA_OPT_IN\x10\x05\x12\x1f\n\x1bMAXIMIZE_CONVERSIONS_OPT_IN\x10\x06\x12\x17\n\x13\x45NHANCED_CPC_OPT_IN\x10\x07\x12\x1a\n\x16SEARCH_PARTNERS_OPT_IN\x10\x08\x12\x1a\n\x16MAXIMIZE_CLICKS_OPT_IN\x10\t\x12\x18\n\x14OPTIMIZE_AD_ROTATION\x10\n\x12\x15\n\x11\x43\x41LLOUT_EXTENSION\x10\x0b\x12\x16\n\x12SITELINK_EXTENSION\x10\x0c\x12\x12\n\x0e\x43\x41LL_EXTENSION\x10\r\x12\x16\n\x12KEYWORD_MATCH_TYPE\x10\x0e\x12\x16\n\x12MOVE_UNUSED_BUDGET\x10\x0f\x42\xec\x01\n!com.google.ads.googleads.v2.enumsB\x17RecommendationTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_RECOMMENDATIONTYPEENUM_RECOMMENDATIONTYPE = _descriptor.EnumDescriptor(
  name='RecommendationType',
  full_name='google.ads.googleads.v2.enums.RecommendationTypeEnum.RecommendationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMPAIGN_BUDGET', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEXT_AD', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_CPA_OPT_IN', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAXIMIZE_CONVERSIONS_OPT_IN', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENHANCED_CPC_OPT_IN', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_PARTNERS_OPT_IN', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAXIMIZE_CLICKS_OPT_IN', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPTIMIZE_AD_ROTATION', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLOUT_EXTENSION', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SITELINK_EXTENSION', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALL_EXTENSION', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD_MATCH_TYPE', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOVE_UNUSED_BUDGET', index=15, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=154,
  serialized_end=529,
)
_sym_db.RegisterEnumDescriptor(_RECOMMENDATIONTYPEENUM_RECOMMENDATIONTYPE)


_RECOMMENDATIONTYPEENUM = _descriptor.Descriptor(
  name='RecommendationTypeEnum',
  full_name='google.ads.googleads.v2.enums.RecommendationTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECOMMENDATIONTYPEENUM_RECOMMENDATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=529,
)

_RECOMMENDATIONTYPEENUM_RECOMMENDATIONTYPE.containing_type = _RECOMMENDATIONTYPEENUM
DESCRIPTOR.message_types_by_name['RecommendationTypeEnum'] = _RECOMMENDATIONTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecommendationTypeEnum = _reflection.GeneratedProtocolMessageType('RecommendationTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _RECOMMENDATIONTYPEENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.recommendation_type_pb2'
  ,
  __doc__ = """Container for enum describing types of recommendations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.RecommendationTypeEnum)
  ))
_sym_db.RegisterMessage(RecommendationTypeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/customer_negative_criterion.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v2.proto.enums import criterion_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/customer_negative_criterion.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\036CustomerNegativeCriterionProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\nIgoogle/ads/googleads_v2/proto/resources/customer_negative_criterion.proto\x12!google.ads.googleads.v2.resources\x1a\x33google/ads/googleads_v2/proto/common/criteria.proto\x1a\x38google/ads/googleads_v2/proto/enums/criterion_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x8a\x05\n\x19\x43ustomerNegativeCriterion\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\x04type\x18\x03 \x01(\x0e\x32>.google.ads.googleads.v2.enums.CriterionTypeEnum.CriterionType\x12I\n\rcontent_label\x18\x04 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.ContentLabelInfoH\x00\x12S\n\x12mobile_application\x18\x05 \x01(\x0b\x32\x35.google.ads.googleads.v2.common.MobileApplicationInfoH\x00\x12T\n\x13mobile_app_category\x18\x06 \x01(\x0b\x32\x35.google.ads.googleads.v2.common.MobileAppCategoryInfoH\x00\x12\x42\n\tplacement\x18\x07 \x01(\x0b\x32-.google.ads.googleads.v2.common.PlacementInfoH\x00\x12I\n\ryoutube_video\x18\x08 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.YouTubeVideoInfoH\x00\x12M\n\x0fyoutube_channel\x18\t \x01(\x0b\x32\x32.google.ads.googleads.v2.common.YouTubeChannelInfoH\x00\x42\x0b\n\tcriterionB\x8b\x02\n%com.google.ads.googleads.v2.resourcesB\x1e\x43ustomerNegativeCriterionProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CUSTOMERNEGATIVECRITERION = _descriptor.Descriptor(
  name='CustomerNegativeCriterion',
  full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_label', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.content_label', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_application', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.mobile_application', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_app_category', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.mobile_app_category', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.placement', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_video', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.youtube_video', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_channel', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.youtube_channel', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='criterion', full_name='google.ads.googleads.v2.resources.CustomerNegativeCriterion.criterion',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=286,
  serialized_end=936,
)

_CUSTOMERNEGATIVECRITERION.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CUSTOMERNEGATIVECRITERION.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2._CRITERIONTYPEENUM_CRITERIONTYPE
_CUSTOMERNEGATIVECRITERION.fields_by_name['content_label'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._CONTENTLABELINFO
_CUSTOMERNEGATIVECRITERION.fields_by_name['mobile_application'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._MOBILEAPPLICATIONINFO
_CUSTOMERNEGATIVECRITERION.fields_by_name['mobile_app_category'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._MOBILEAPPCATEGORYINFO
_CUSTOMERNEGATIVECRITERION.fields_by_name['placement'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._PLACEMENTINFO
_CUSTOMERNEGATIVECRITERION.fields_by_name['youtube_video'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._YOUTUBEVIDEOINFO
_CUSTOMERNEGATIVECRITERION.fields_by_name['youtube_channel'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._YOUTUBECHANNELINFO
_CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion'].fields.append(
  _CUSTOMERNEGATIVECRITERION.fields_by_name['content_label'])
_CUSTOMERNEGATIVECRITERION.fields_by_name['content_label'].containing_oneof = _CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion']
_CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion'].fields.append(
  _CUSTOMERNEGATIVECRITERION.fields_by_name['mobile_application'])
_CUSTOMERNEGATIVECRITERION.fields_by_name['mobile_application'].containing_oneof = _CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion']
_CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion'].fields.append(
  _CUSTOMERNEGATIVECRITERION.fields_by_name['mobile_app_category'])
_CUSTOMERNEGATIVECRITERION.fields_by_name['mobile_app_category'].containing_oneof = _CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion']
_CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion'].fields.append(
  _CUSTOMERNEGATIVECRITERION.fields_by_name['placement'])
_CUSTOMERNEGATIVECRITERION.fields_by_name['placement'].containing_oneof = _CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion']
_CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion'].fields.append(
  _CUSTOMERNEGATIVECRITERION.fields_by_name['youtube_video'])
_CUSTOMERNEGATIVECRITERION.fields_by_name['youtube_video'].containing_oneof = _CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion']
_CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion'].fields.append(
  _CUSTOMERNEGATIVECRITERION.fields_by_name['youtube_channel'])
_CUSTOMERNEGATIVECRITERION.fields_by_name['youtube_channel'].containing_oneof = _CUSTOMERNEGATIVECRITERION.oneofs_by_name['criterion']
DESCRIPTOR.message_types_by_name['CustomerNegativeCriterion'] = _CUSTOMERNEGATIVECRITERION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustomerNegativeCriterion = _reflection.GeneratedProtocolMessageType('CustomerNegativeCriterion', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMERNEGATIVECRITERION,
  __module__ = 'google.ads.googleads_v2.proto.resources.customer_negative_criterion_pb2'
  ,
  __doc__ = """A negative criterion for exclusions at the customer level.
  
  
  Attributes:
      resource_name:
          The resource name of the customer negative criterion. Customer
          negative criterion resource names have the form:  ``customers/
          {customer_id}/customerNegativeCriteria/{criterion_id}``
      id:
          The ID of the criterion.
      type:
          The type of the criterion.
      criterion:
          The customer negative criterion.  Exactly one must be set.
      content_label:
          ContentLabel.
      mobile_application:
          MobileApplication.
      mobile_app_category:
          MobileAppCategory.
      placement:
          Placement.
      youtube_video:
          YouTube Video.
      youtube_channel:
          YouTube Channel.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.CustomerNegativeCriterion)
  ))
_sym_db.RegisterMessage(CustomerNegativeCriterion)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/customer_client_link_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import customer_client_link_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__client__link__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/customer_client_link_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\036CustomerClientLinkServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nIgoogle/ads/googleads_v1/proto/services/customer_client_link_service.proto\x12 google.ads.googleads.v1.services\x1a\x42google/ads/googleads_v1/proto/resources/customer_client_link.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\"5\n\x1cGetCustomerClientLinkRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x88\x01\n\x1fMutateCustomerClientLinkRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12P\n\toperation\x18\x02 \x01(\x0b\x32=.google.ads.googleads.v1.services.CustomerClientLinkOperation\"\xed\x01\n\x1b\x43ustomerClientLinkOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12G\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x35.google.ads.googleads.v1.resources.CustomerClientLinkH\x00\x12G\n\x06update\x18\x02 \x01(\x0b\x32\x35.google.ads.googleads.v1.resources.CustomerClientLinkH\x00\x42\x0b\n\toperation\"t\n MutateCustomerClientLinkResponse\x12P\n\x06result\x18\x01 \x01(\x0b\x32@.google.ads.googleads.v1.services.MutateCustomerClientLinkResult\"7\n\x1eMutateCustomerClientLinkResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xd4\x03\n\x19\x43ustomerClientLinkService\x12\xcd\x01\n\x15GetCustomerClientLink\x12>.google.ads.googleads.v1.services.GetCustomerClientLinkRequest\x1a\x35.google.ads.googleads.v1.resources.CustomerClientLink\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1/{resource_name=customers/*/customerClientLinks/*}\x12\xe6\x01\n\x18MutateCustomerClientLink\x12\x41.google.ads.googleads.v1.services.MutateCustomerClientLinkRequest\x1a\x42.google.ads.googleads.v1.services.MutateCustomerClientLinkResponse\"C\x82\xd3\xe4\x93\x02=\"8/v1/customers/{customer_id=*}/customerClientLinks:mutate:\x01*B\x85\x02\n$com.google.ads.googleads.v1.servicesB\x1e\x43ustomerClientLinkServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__client__link__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_GETCUSTOMERCLIENTLINKREQUEST = _descriptor.Descriptor(
  name='GetCustomerClientLinkRequest',
  full_name='google.ads.googleads.v1.services.GetCustomerClientLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetCustomerClientLinkRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=328,
)


_MUTATECUSTOMERCLIENTLINKREQUEST = _descriptor.Descriptor(
  name='MutateCustomerClientLinkRequest',
  full_name='google.ads.googleads.v1.services.MutateCustomerClientLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.MutateCustomerClientLinkRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.MutateCustomerClientLinkRequest.operation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=467,
)


_CUSTOMERCLIENTLINKOPERATION = _descriptor.Descriptor(
  name='CustomerClientLinkOperation',
  full_name='google.ads.googleads.v1.services.CustomerClientLinkOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v1.services.CustomerClientLinkOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v1.services.CustomerClientLinkOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v1.services.CustomerClientLinkOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.CustomerClientLinkOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=470,
  serialized_end=707,
)


_MUTATECUSTOMERCLIENTLINKRESPONSE = _descriptor.Descriptor(
  name='MutateCustomerClientLinkResponse',
  full_name='google.ads.googleads.v1.services.MutateCustomerClientLinkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='google.ads.googleads.v1.services.MutateCustomerClientLinkResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=825,
)


_MUTATECUSTOMERCLIENTLINKRESULT = _descriptor.Descriptor(
  name='MutateCustomerClientLinkResult',
  full_name='google.ads.googleads.v1.services.MutateCustomerClientLinkResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.MutateCustomerClientLinkResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=882,
)

_MUTATECUSTOMERCLIENTLINKREQUEST.fields_by_name['operation'].message_type = _CUSTOMERCLIENTLINKOPERATION
_CUSTOMERCLIENTLINKOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CUSTOMERCLIENTLINKOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__client__link__pb2._CUSTOMERCLIENTLINK
_CUSTOMERCLIENTLINKOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__client__link__pb2._CUSTOMERCLIENTLINK
_CUSTOMERCLIENTLINKOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMERCLIENTLINKOPERATION.fields_by_name['create'])
_CUSTOMERCLIENTLINKOPERATION.fields_by_name['create'].containing_oneof = _CUSTOMERCLIENTLINKOPERATION.oneofs_by_name['operation']
_CUSTOMERCLIENTLINKOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMERCLIENTLINKOPERATION.fields_by_name['update'])
_CUSTOMERCLIENTLINKOPERATION.fields_by_name['update'].containing_oneof = _CUSTOMERCLIENTLINKOPERATION.oneofs_by_name['operation']
_MUTATECUSTOMERCLIENTLINKRESPONSE.fields_by_name['result'].message_type = _MUTATECUSTOMERCLIENTLINKRESULT
DESCRIPTOR.message_types_by_name['GetCustomerClientLinkRequest'] = _GETCUSTOMERCLIENTLINKREQUEST
DESCRIPTOR.message_types_by_name['MutateCustomerClientLinkRequest'] = _MUTATECUSTOMERCLIENTLINKREQUEST
DESCRIPTOR.message_types_by_name['CustomerClientLinkOperation'] = _CUSTOMERCLIENTLINKOPERATION
DESCRIPTOR.message_types_by_name['MutateCustomerClientLinkResponse'] = _MUTATECUSTOMERCLIENTLINKRESPONSE
DESCRIPTOR.message_types_by_name['MutateCustomerClientLinkResult'] = _MUTATECUSTOMERCLIENTLINKRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCustomerClientLinkRequest = _reflection.GeneratedProtocolMessageType('GetCustomerClientLinkRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCUSTOMERCLIENTLINKREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_client_link_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerClientLinkService.GetCustomerClientLink][google.ads.googleads.v1.services.CustomerClientLinkService.GetCustomerClientLink].
  
  
  Attributes:
      resource_name:
          The resource name of the customer client link to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetCustomerClientLinkRequest)
  ))
_sym_db.RegisterMessage(GetCustomerClientLinkRequest)

MutateCustomerClientLinkRequest = _reflection.GeneratedProtocolMessageType('MutateCustomerClientLinkRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERCLIENTLINKREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_client_link_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerClientLinkService.MutateCustomerClientLink][google.ads.googleads.v1.services.CustomerClientLinkService.MutateCustomerClientLink].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose customer link are being modified.
      operation:
          The operation to perform on the individual CustomerClientLink.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomerClientLinkRequest)
  ))
_sym_db.RegisterMessage(MutateCustomerClientLinkRequest)

CustomerClientLinkOperation = _reflection.GeneratedProtocolMessageType('CustomerClientLinkOperation', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMERCLIENTLINKOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_client_link_service_pb2'
  ,
  __doc__ = """A single operation (create, update) on a CustomerClientLink.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          link.
      update:
          Update operation: The link is expected to have a valid
          resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.CustomerClientLinkOperation)
  ))
_sym_db.RegisterMessage(CustomerClientLinkOperation)

MutateCustomerClientLinkResponse = _reflection.GeneratedProtocolMessageType('MutateCustomerClientLinkResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERCLIENTLINKRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_client_link_service_pb2'
  ,
  __doc__ = """Response message for a CustomerClientLink mutate.
  
  
  Attributes:
      result:
          A result that identifies the resource affected by the mutate
          request.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomerClientLinkResponse)
  ))
_sym_db.RegisterMessage(MutateCustomerClientLinkResponse)

MutateCustomerClientLinkResult = _reflection.GeneratedProtocolMessageType('MutateCustomerClientLinkResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERCLIENTLINKRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_client_link_service_pb2'
  ,
  __doc__ = """The result for a single customer client link mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomerClientLinkResult)
  ))
_sym_db.RegisterMessage(MutateCustomerClientLinkResult)


DESCRIPTOR._options = None

_CUSTOMERCLIENTLINKSERVICE = _descriptor.ServiceDescriptor(
  name='CustomerClientLinkService',
  full_name='google.ads.googleads.v1.services.CustomerClientLinkService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=885,
  serialized_end=1353,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCustomerClientLink',
    full_name='google.ads.googleads.v1.services.CustomerClientLinkService.GetCustomerClientLink',
    index=0,
    containing_service=None,
    input_type=_GETCUSTOMERCLIENTLINKREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__client__link__pb2._CUSTOMERCLIENTLINK,
    serialized_options=_b('\202\323\344\223\0027\0225/v1/{resource_name=customers/*/customerClientLinks/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCustomerClientLink',
    full_name='google.ads.googleads.v1.services.CustomerClientLinkService.MutateCustomerClientLink',
    index=1,
    containing_service=None,
    input_type=_MUTATECUSTOMERCLIENTLINKREQUEST,
    output_type=_MUTATECUSTOMERCLIENTLINKRESPONSE,
    serialized_options=_b('\202\323\344\223\002=\"8/v1/customers/{customer_id=*}/customerClientLinks:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CUSTOMERCLIENTLINKSERVICE)

DESCRIPTOR.services_by_name['CustomerClientLinkService'] = _CUSTOMERCLIENTLINKSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import bidding_strategy_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_bidding__strategy__pb2
from google.ads.google_ads.v2.proto.services import bidding_strategy_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2


class BiddingStrategyServiceStub(object):
  """Proto file describing the Bidding Strategy service.

  Service to manage bidding strategies.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetBiddingStrategy = channel.unary_unary(
        '/google.ads.googleads.v2.services.BiddingStrategyService/GetBiddingStrategy',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2.GetBiddingStrategyRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_bidding__strategy__pb2.BiddingStrategy.FromString,
        )
    self.MutateBiddingStrategies = channel.unary_unary(
        '/google.ads.googleads.v2.services.BiddingStrategyService/MutateBiddingStrategies',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2.MutateBiddingStrategiesRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2.MutateBiddingStrategiesResponse.FromString,
        )


class BiddingStrategyServiceServicer(object):
  """Proto file describing the Bidding Strategy service.

  Service to manage bidding strategies.
  """

  def GetBiddingStrategy(self, request, context):
    """Returns the requested bidding strategy in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateBiddingStrategies(self, request, context):
    """Creates, updates, or removes bidding strategies. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_BiddingStrategyServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetBiddingStrategy': grpc.unary_unary_rpc_method_handler(
          servicer.GetBiddingStrategy,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2.GetBiddingStrategyRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_bidding__strategy__pb2.BiddingStrategy.SerializeToString,
      ),
      'MutateBiddingStrategies': grpc.unary_unary_rpc_method_handler(
          servicer.MutateBiddingStrategies,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2.MutateBiddingStrategiesRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2.MutateBiddingStrategiesResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.BiddingStrategyService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import mutate_job_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_mutate__job__pb2
from google.ads.google_ads.v1.proto.services import mutate_job_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2


class MutateJobServiceStub(object):
  """Proto file describing the MutateJobService.

  Service to manage mutate jobs.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateMutateJob = channel.unary_unary(
        '/google.ads.googleads.v1.services.MutateJobService/CreateMutateJob',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.CreateMutateJobRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.CreateMutateJobResponse.FromString,
        )
    self.GetMutateJob = channel.unary_unary(
        '/google.ads.googleads.v1.services.MutateJobService/GetMutateJob',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.GetMutateJobRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_mutate__job__pb2.MutateJob.FromString,
        )
    self.ListMutateJobResults = channel.unary_unary(
        '/google.ads.googleads.v1.services.MutateJobService/ListMutateJobResults',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.ListMutateJobResultsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.ListMutateJobResultsResponse.FromString,
        )
    self.RunMutateJob = channel.unary_unary(
        '/google.ads.googleads.v1.services.MutateJobService/RunMutateJob',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.RunMutateJobRequest.SerializeToString,
        response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
    self.AddMutateJobOperations = channel.unary_unary(
        '/google.ads.googleads.v1.services.MutateJobService/AddMutateJobOperations',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.AddMutateJobOperationsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.AddMutateJobOperationsResponse.FromString,
        )


class MutateJobServiceServicer(object):
  """Proto file describing the MutateJobService.

  Service to manage mutate jobs.
  """

  def CreateMutateJob(self, request, context):
    """Creates a mutate job.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetMutateJob(self, request, context):
    """Returns the mutate job.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListMutateJobResults(self, request, context):
    """Returns the results of the mutate job. The job must be done.
    Supports standard list paging.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RunMutateJob(self, request, context):
    """Runs the mutate job.

    The Operation.metadata field type is MutateJobMetadata. When finished, the
    long running operation will not contain errors or a response. Instead, use
    ListMutateJobResults to get the results of the job.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddMutateJobOperations(self, request, context):
    """Add operations to the mutate job.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MutateJobServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateMutateJob': grpc.unary_unary_rpc_method_handler(
          servicer.CreateMutateJob,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.CreateMutateJobRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.CreateMutateJobResponse.SerializeToString,
      ),
      'GetMutateJob': grpc.unary_unary_rpc_method_handler(
          servicer.GetMutateJob,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.GetMutateJobRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_mutate__job__pb2.MutateJob.SerializeToString,
      ),
      'ListMutateJobResults': grpc.unary_unary_rpc_method_handler(
          servicer.ListMutateJobResults,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.ListMutateJobResultsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.ListMutateJobResultsResponse.SerializeToString,
      ),
      'RunMutateJob': grpc.unary_unary_rpc_method_handler(
          servicer.RunMutateJob,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.RunMutateJobRequest.FromString,
          response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
      ),
      'AddMutateJobOperations': grpc.unary_unary_rpc_method_handler(
          servicer.AddMutateJobOperations,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.AddMutateJobOperationsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_mutate__job__service__pb2.AddMutateJobOperationsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.MutateJobService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/customer_manager_link_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import customer_manager_link_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__manager__link__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/customer_manager_link_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\037CustomerManagerLinkServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nJgoogle/ads/googleads_v1/proto/services/customer_manager_link_service.proto\x12 google.ads.googleads.v1.services\x1a\x43google/ads/googleads_v1/proto/resources/customer_manager_link.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"6\n\x1dGetCustomerManagerLinkRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x8b\x01\n MutateCustomerManagerLinkRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12R\n\noperations\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v1.services.CustomerManagerLinkOperation\"\xa6\x01\n\x1c\x43ustomerManagerLinkOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12H\n\x06update\x18\x02 \x01(\x0b\x32\x36.google.ads.googleads.v1.resources.CustomerManagerLinkH\x00\x42\x0b\n\toperation\"w\n!MutateCustomerManagerLinkResponse\x12R\n\x07results\x18\x01 \x03(\x0b\x32\x41.google.ads.googleads.v1.services.MutateCustomerManagerLinkResult\"8\n\x1fMutateCustomerManagerLinkResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xdd\x03\n\x1a\x43ustomerManagerLinkService\x12\xd1\x01\n\x16GetCustomerManagerLink\x12?.google.ads.googleads.v1.services.GetCustomerManagerLinkRequest\x1a\x36.google.ads.googleads.v1.resources.CustomerManagerLink\">\x82\xd3\xe4\x93\x02\x38\x12\x36/v1/{resource_name=customers/*/customerManagerLinks/*}\x12\xea\x01\n\x19MutateCustomerManagerLink\x12\x42.google.ads.googleads.v1.services.MutateCustomerManagerLinkRequest\x1a\x43.google.ads.googleads.v1.services.MutateCustomerManagerLinkResponse\"D\x82\xd3\xe4\x93\x02>\"9/v1/customers/{customer_id=*}/customerManagerLinks:mutate:\x01*B\x86\x02\n$com.google.ads.googleads.v1.servicesB\x1f\x43ustomerManagerLinkServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__manager__link__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETCUSTOMERMANAGERLINKREQUEST = _descriptor.Descriptor(
  name='GetCustomerManagerLinkRequest',
  full_name='google.ads.googleads.v1.services.GetCustomerManagerLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetCustomerManagerLinkRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=299,
)


_MUTATECUSTOMERMANAGERLINKREQUEST = _descriptor.Descriptor(
  name='MutateCustomerManagerLinkRequest',
  full_name='google.ads.googleads.v1.services.MutateCustomerManagerLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.MutateCustomerManagerLinkRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.MutateCustomerManagerLinkRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=441,
)


_CUSTOMERMANAGERLINKOPERATION = _descriptor.Descriptor(
  name='CustomerManagerLinkOperation',
  full_name='google.ads.googleads.v1.services.CustomerManagerLinkOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v1.services.CustomerManagerLinkOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v1.services.CustomerManagerLinkOperation.update', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.CustomerManagerLinkOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=444,
  serialized_end=610,
)


_MUTATECUSTOMERMANAGERLINKRESPONSE = _descriptor.Descriptor(
  name='MutateCustomerManagerLinkResponse',
  full_name='google.ads.googleads.v1.services.MutateCustomerManagerLinkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.MutateCustomerManagerLinkResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=731,
)


_MUTATECUSTOMERMANAGERLINKRESULT = _descriptor.Descriptor(
  name='MutateCustomerManagerLinkResult',
  full_name='google.ads.googleads.v1.services.MutateCustomerManagerLinkResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.MutateCustomerManagerLinkResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=789,
)

_MUTATECUSTOMERMANAGERLINKREQUEST.fields_by_name['operations'].message_type = _CUSTOMERMANAGERLINKOPERATION
_CUSTOMERMANAGERLINKOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CUSTOMERMANAGERLINKOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__manager__link__pb2._CUSTOMERMANAGERLINK
_CUSTOMERMANAGERLINKOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMERMANAGERLINKOPERATION.fields_by_name['update'])
_CUSTOMERMANAGERLINKOPERATION.fields_by_name['update'].containing_oneof = _CUSTOMERMANAGERLINKOPERATION.oneofs_by_name['operation']
_MUTATECUSTOMERMANAGERLINKRESPONSE.fields_by_name['results'].message_type = _MUTATECUSTOMERMANAGERLINKRESULT
DESCRIPTOR.message_types_by_name['GetCustomerManagerLinkRequest'] = _GETCUSTOMERMANAGERLINKREQUEST
DESCRIPTOR.message_types_by_name['MutateCustomerManagerLinkRequest'] = _MUTATECUSTOMERMANAGERLINKREQUEST
DESCRIPTOR.message_types_by_name['CustomerManagerLinkOperation'] = _CUSTOMERMANAGERLINKOPERATION
DESCRIPTOR.message_types_by_name['MutateCustomerManagerLinkResponse'] = _MUTATECUSTOMERMANAGERLINKRESPONSE
DESCRIPTOR.message_types_by_name['MutateCustomerManagerLinkResult'] = _MUTATECUSTOMERMANAGERLINKRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCustomerManagerLinkRequest = _reflection.GeneratedProtocolMessageType('GetCustomerManagerLinkRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCUSTOMERMANAGERLINKREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_manager_link_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerManagerLinkService.GetCustomerManagerLink][google.ads.googleads.v1.services.CustomerManagerLinkService.GetCustomerManagerLink].
  
  
  Attributes:
      resource_name:
          The resource name of the CustomerManagerLink to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetCustomerManagerLinkRequest)
  ))
_sym_db.RegisterMessage(GetCustomerManagerLinkRequest)

MutateCustomerManagerLinkRequest = _reflection.GeneratedProtocolMessageType('MutateCustomerManagerLinkRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERMANAGERLINKREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_manager_link_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerManagerLinkService.MutateCustomerManagerLink][google.ads.googleads.v1.services.CustomerManagerLinkService.MutateCustomerManagerLink].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose customer manager links are being
          modified.
      operations:
          The list of operations to perform on individual customer
          manager links.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomerManagerLinkRequest)
  ))
_sym_db.RegisterMessage(MutateCustomerManagerLinkRequest)

CustomerManagerLinkOperation = _reflection.GeneratedProtocolMessageType('CustomerManagerLinkOperation', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMERMANAGERLINKOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_manager_link_service_pb2'
  ,
  __doc__ = """Updates the status of a CustomerManagerLink. The following actions are
  possible: 1. Update operation with status ACTIVE accepts a pending
  invitation. 2. Update operation with status REFUSED declines a pending
  invitation. 3. Update operation with status INACTIVE terminates link to
  manager.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      update:
          Update operation: The link is expected to have a valid
          resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.CustomerManagerLinkOperation)
  ))
_sym_db.RegisterMessage(CustomerManagerLinkOperation)

MutateCustomerManagerLinkResponse = _reflection.GeneratedProtocolMessageType('MutateCustomerManagerLinkResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERMANAGERLINKRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_manager_link_service_pb2'
  ,
  __doc__ = """Response message for a CustomerManagerLink mutate.
  
  
  Attributes:
      results:
          A result that identifies the resource affected by the mutate
          request.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomerManagerLinkResponse)
  ))
_sym_db.RegisterMessage(MutateCustomerManagerLinkResponse)

MutateCustomerManagerLinkResult = _reflection.GeneratedProtocolMessageType('MutateCustomerManagerLinkResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERMANAGERLINKRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_manager_link_service_pb2'
  ,
  __doc__ = """The result for the customer manager link mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomerManagerLinkResult)
  ))
_sym_db.RegisterMessage(MutateCustomerManagerLinkResult)


DESCRIPTOR._options = None

_CUSTOMERMANAGERLINKSERVICE = _descriptor.ServiceDescriptor(
  name='CustomerManagerLinkService',
  full_name='google.ads.googleads.v1.services.CustomerManagerLinkService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=792,
  serialized_end=1269,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCustomerManagerLink',
    full_name='google.ads.googleads.v1.services.CustomerManagerLinkService.GetCustomerManagerLink',
    index=0,
    containing_service=None,
    input_type=_GETCUSTOMERMANAGERLINKREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__manager__link__pb2._CUSTOMERMANAGERLINK,
    serialized_options=_b('\202\323\344\223\0028\0226/v1/{resource_name=customers/*/customerManagerLinks/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCustomerManagerLink',
    full_name='google.ads.googleads.v1.services.CustomerManagerLinkService.MutateCustomerManagerLink',
    index=1,
    containing_service=None,
    input_type=_MUTATECUSTOMERMANAGERLINKREQUEST,
    output_type=_MUTATECUSTOMERMANAGERLINKRESPONSE,
    serialized_options=_b('\202\323\344\223\002>\"9/v1/customers/{customer_id=*}/customerManagerLinks:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CUSTOMERMANAGERLINKSERVICE)

DESCRIPTOR.services_by_name['CustomerManagerLinkService'] = _CUSTOMERMANAGERLINKSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/advertising_channel_sub_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/advertising_channel_sub_type.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\036AdvertisingChannelSubTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\nFgoogle/ads/googleads_v2/proto/enums/advertising_channel_sub_type.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\x95\x03\n\x1d\x41\x64vertisingChannelSubTypeEnum\"\xf3\x02\n\x19\x41\x64vertisingChannelSubType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x15\n\x11SEARCH_MOBILE_APP\x10\x02\x12\x16\n\x12\x44ISPLAY_MOBILE_APP\x10\x03\x12\x12\n\x0eSEARCH_EXPRESS\x10\x04\x12\x13\n\x0f\x44ISPLAY_EXPRESS\x10\x05\x12\x16\n\x12SHOPPING_SMART_ADS\x10\x06\x12\x14\n\x10\x44ISPLAY_GMAIL_AD\x10\x07\x12\x1a\n\x16\x44ISPLAY_SMART_CAMPAIGN\x10\x08\x12\x13\n\x0fVIDEO_OUTSTREAM\x10\t\x12\x10\n\x0cVIDEO_ACTION\x10\n\x12\x17\n\x13VIDEO_NON_SKIPPABLE\x10\x0b\x12\x10\n\x0c\x41PP_CAMPAIGN\x10\x0c\x12\x1f\n\x1b\x41PP_CAMPAIGN_FOR_ENGAGEMENT\x10\r\x12#\n\x1fSHOPPING_COMPARISON_LISTING_ADS\x10\x0f\x42\xf3\x01\n!com.google.ads.googleads.v2.enumsB\x1e\x41\x64vertisingChannelSubTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_ADVERTISINGCHANNELSUBTYPEENUM_ADVERTISINGCHANNELSUBTYPE = _descriptor.EnumDescriptor(
  name='AdvertisingChannelSubType',
  full_name='google.ads.googleads.v2.enums.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_MOBILE_APP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISPLAY_MOBILE_APP', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_EXPRESS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISPLAY_EXPRESS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOPPING_SMART_ADS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISPLAY_GMAIL_AD', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISPLAY_SMART_CAMPAIGN', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_OUTSTREAM', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_ACTION', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_NON_SKIPPABLE', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_CAMPAIGN', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_CAMPAIGN_FOR_ENGAGEMENT', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOPPING_COMPARISON_LISTING_ADS', index=14, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=170,
  serialized_end=541,
)
_sym_db.RegisterEnumDescriptor(_ADVERTISINGCHANNELSUBTYPEENUM_ADVERTISINGCHANNELSUBTYPE)


_ADVERTISINGCHANNELSUBTYPEENUM = _descriptor.Descriptor(
  name='AdvertisingChannelSubTypeEnum',
  full_name='google.ads.googleads.v2.enums.AdvertisingChannelSubTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADVERTISINGCHANNELSUBTYPEENUM_ADVERTISINGCHANNELSUBTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=541,
)

_ADVERTISINGCHANNELSUBTYPEENUM_ADVERTISINGCHANNELSUBTYPE.containing_type = _ADVERTISINGCHANNELSUBTYPEENUM
DESCRIPTOR.message_types_by_name['AdvertisingChannelSubTypeEnum'] = _ADVERTISINGCHANNELSUBTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdvertisingChannelSubTypeEnum = _reflection.GeneratedProtocolMessageType('AdvertisingChannelSubTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _ADVERTISINGCHANNELSUBTYPEENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.advertising_channel_sub_type_pb2'
  ,
  __doc__ = """An immutable specialization of an Advertising Channel.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.AdvertisingChannelSubTypeEnum)
  ))
_sym_db.RegisterMessage(AdvertisingChannelSubTypeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
